==> kubernetes-model-gatewayapi-6.4.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/TLSRouteStatusFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TLSRouteStatusFluent<A extends TLSRouteStatusFluent<A>> extends Fluent<A>{
  public A addToParents(Integer index,RouteParentStatus item);
  public A setToParents(Integer index,RouteParentStatus item);
  public A addToParents(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.RouteParentStatus... items);
  public A addAllToParents(Collection<RouteParentStatus> items);
  public A removeFromParents(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.RouteParentStatus... items);
  public A removeAllFromParents(Collection<RouteParentStatus> items);
  public A removeMatchingFromParents(Predicate<RouteParentStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParents instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RouteParentStatus> getParents();
  public List<RouteParentStatus> buildParents();
  public RouteParentStatus buildParent(Integer index);
  public RouteParentStatus buildFirstParent();
  public RouteParentStatus buildLastParent();
  public RouteParentStatus buildMatchingParent(Predicate<RouteParentStatusBuilder> predicate);
  public Boolean hasMatchingParent(Predicate<RouteParentStatusBuilder> predicate);
  public A withParents(List<RouteParentStatus> parents);
  public A withParents(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.RouteParentStatus... parents);
  public Boolean hasParents();
  public TLSRouteStatusFluent.ParentsNested<A> addNewParent();
  public TLSRouteStatusFluent.ParentsNested<A> addNewParentLike(RouteParentStatus item);
  public TLSRouteStatusFluent.ParentsNested<A> setNewParentLike(Integer index,RouteParentStatus item);
  public TLSRouteStatusFluent.ParentsNested<A> editParent(Integer index);
  public TLSRouteStatusFluent.ParentsNested<A> editFirstParent();
  public TLSRouteStatusFluent.ParentsNested<A> editLastParent();
  public TLSRouteStatusFluent.ParentsNested<A> editMatchingParent(Predicate<RouteParentStatusBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ParentsNested<N> extends Nested<N>,RouteParentStatusFluent<TLSRouteStatusFluent.ParentsNested<N>>{
    public N and();
    public N endParent();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/TLSRouteStatusFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.RouteParentStatus;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.RouteParentStatusBuilder;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.RouteParentStatusFluent;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TLSRouteStatusFluent<A extends TLSRouteStatusFluent<A>> extends Fluent<A>{
  public A addToParents(Integer index,RouteParentStatus item);
  public A setToParents(Integer index,RouteParentStatus item);
  public A addToParents(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.RouteParentStatus... items);
  public A addAllToParents(Collection<RouteParentStatus> items);
  public A removeFromParents(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.RouteParentStatus... items);
  public A removeAllFromParents(Collection<RouteParentStatus> items);
  public A removeMatchingFromParents(Predicate<RouteParentStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParents instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RouteParentStatus> getParents();
  public List<RouteParentStatus> buildParents();
  public RouteParentStatus buildParent(Integer index);
  public RouteParentStatus buildFirstParent();
  public RouteParentStatus buildLastParent();
  public RouteParentStatus buildMatchingParent(Predicate<RouteParentStatusBuilder> predicate);
  public Boolean hasMatchingParent(Predicate<RouteParentStatusBuilder> predicate);
  public A withParents(List<RouteParentStatus> parents);
  public A withParents(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.RouteParentStatus... parents);
  public Boolean hasParents();
  public TLSRouteStatusFluent.ParentsNested<A> addNewParent();
  public TLSRouteStatusFluent.ParentsNested<A> addNewParentLike(RouteParentStatus item);
  public TLSRouteStatusFluent.ParentsNested<A> setNewParentLike(Integer index,RouteParentStatus item);
  public TLSRouteStatusFluent.ParentsNested<A> editParent(Integer index);
  public TLSRouteStatusFluent.ParentsNested<A> editFirstParent();
  public TLSRouteStatusFluent.ParentsNested<A> editLastParent();
  public TLSRouteStatusFluent.ParentsNested<A> editMatchingParent(Predicate<RouteParentStatusBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ParentsNested<N> extends Nested<N>,RouteParentStatusFluent<TLSRouteStatusFluent.ParentsNested<N>>{
    public N and();
    public N endParent();
    
  }
  
}
